<!-- !split -->
<!-- jupyter-book 04_04_testdoc.md -->
# Project: Compute a Probability

<!-- Minimalistic exercise -->

<div id="demo:ex:2"></div>

What is the probability of getting a number between 0.5 and 0.6 when
drawing uniformly distributed random numbers from the interval $[0,1)$?

*Hint.* 
To answer this question empirically, let a program
draw $N$ such random numbers using Python's standard `random` module,
count how many of them, $M$, that fall in the interval $(0.5,0.6)$, and
compute the probability as $M/N$.



At the end we have a list because that caused problems in LaTeX
in previous DocOnce versions:

1. item1
2. item2

